from abc import ABC, abstractmethod


class DutMeasurement(ABC):
    """
    Interface for DUT measurements
    """
    @abstractmethod
    def get_dut_measurements(self, set_name):
        """
        Performs the measurements according to the set name and
        returns a dictionary with signal names a keys and scalar values
        """
        pass

    @abstractmethod
    def get_dut_signal_names(self):
        """
        Returns a list of names used as keys used in the dut measurements dictionary
        """
        pass

    @abstractmethod
    def get_dut_reference_signal_names(self):
        """
        Returns a list of signal names used for stability checks
        """
        pass

    @abstractmethod
    def get_dut_max_delta_signals(self):
        """
        Return the maximum deltas of the reference signals
        """

    @abstractmethod
    def get_measurement_set_names(self):
        """
        Names /  string identifiers of the different measurement sets which are performed at each temperature/humidity
        """
        pass
